<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

return [

	// A
	'aide_non_disponible' => 'Aquela part de l’ajuda en linha non es encara disponibla per aquesta lenga.',
	'avis_acces_interdit' => 'Accès proïbit.',
	'avis_article_modifie' => 'Atencion, @nom_auteur_modif@ a trabalhat sus aquel article fa @date_diff@ minutas',
	'avis_aucun_resultat' => 'Minga de resultat.',
	'avis_chemin_invalide_1' => 'Lo camin qu’avètz chausit',
	'avis_chemin_invalide_2' => 'non sembla valid. Vorgatz tornar a la pàgina anteriora per verificar li informacions fornidi.',
	'avis_connexion_echec_1' => 'La conexion au servidor SQL s’es encalada.',
	'avis_connexion_echec_2' => 'Tornatz a la pàgina anteriora, e verificatz li informacions qu’avètz fornidi.',
	'avis_connexion_echec_3' => '<b>N.B.</b> Sus tot plen de servidors, devètz <b>demandar</b> qu’activen lo vòstre accès a la basa SQL avans de la poder utilizar. Se non vos podètz connectar, verificatz qu’augatz ben realizat aqueu procediment.', # MODIF
	'avis_connexion_ldap_echec_1' => 'La connexion au servidor LDAP s’es encalada.',
	'avis_connexion_ldap_echec_2' => 'Tornatz a la pàgina anteriora, e verificatz li informacions qu’avètz fornidi. ',
	'avis_connexion_ldap_echec_3' => 'Alternativament, non utilizetz lo supòrt LDAP per importar d’utilizaires.', # MODIF
	'avis_deplacement_rubrique' => 'Atention! Aquela rubrica conten @contient_breves@ brèvas@scb@: se la desplaçatz, vorretz ben oscar aquela casa de confirmacion.',
	'avis_erreur_connexion_mysql' => 'Error de connexion SQL',
	'avis_espace_interdit' => '<b>Espaci proïbit</b><p>SPIP es ja installat.', # MODIF
	'avis_lecture_noms_bases_1' => 'Lo programa d’installacion non a pas legir lu noms dei basas de donadas installadi.',
	'avis_lecture_noms_bases_2' => 'Sia minga de basa es disponibla, sia la foncion que permete d’entierar li basas es estada desactivada per de rasons de seguretat (aquò es lo cas a cò de plusors aubergadors).',
	'avis_lecture_noms_bases_3' => 'Dins la segonda alternativa, es probable qu’una basa que pòrta lo vòstre nom de login sia utilizabla:',
	'avis_non_acces_page' => 'Non podètz accedir a aquela pàgina.',
	'avis_operation_echec' => 'L’operacion s’es encalada.',
	'avis_suppression_base' => 'ATENCION, suprimir li donadas es irreversible',

	// B
	'bouton_acces_ldap' => 'Apondre l’accès a LDAP >>',
	'bouton_ajouter' => 'Apondre',
	'bouton_demande_publication' => 'Demandar la publicacion d’aquest article',
	'bouton_effacer_tout' => 'O esfaçar tot',
	'bouton_envoyer_message' => 'Messatge definitiu: mandar',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Afichar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Afichar dins la tiera dei redactors connectats', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Mandar lu anoncis a l’adreiça:',
	'bouton_radio_envoi_liste_nouveautes' => 'Mandar la tiera dei novetats',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Non aparéisser dins la tiera dei redactors', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Non mandar d’anoncis editoriaus',
	'bouton_redirection' => 'TORNAR DIRIGIR',
	'bouton_relancer_installation' => 'Tornar lançar l’installacion',
	'bouton_suivant' => 'Seguent',
	'bouton_tenter_recuperation' => 'Assaiar de reparar',
	'bouton_test_proxy' => 'Assaiar lo proxy',
	'bouton_vider_cache' => 'Vuar l’escondedor',

	// C
	'cache_modifiable_webmestre' => 'Lo webmèstre dau sit pòu modificar aquestu paramètres.', # MODIF
	'calendrier_synchro' => 'S’utilizatz un logiciau d’agenda compatible <b>iCal</b>, lo podètz sincronizar embai informacions d’aquest sit.',

	// D
	'date_mot_heures' => 'oras',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Adreiça de l’annuari',
	'entree_adresse_email' => 'La vòstra adreiça e-mail',
	'entree_base_donnee_1' => 'Adreiça de la basa de donadas',
	'entree_base_donnee_2' => '(Sovent, aquela adreiça correspònde a aquela dau vòstre sit, de còups correspònde a la mençon "localhost", de còups, si laissa vueia completament.)',
	'entree_biographie' => 'Biografia corta, en quaucu mots.',
	'entree_chemin_acces' => '<b>Intrar</b> lo camin d’accès:',
	'entree_cle_pgp' => 'La vòstra clau PGP',
	'entree_contenu_rubrique' => '(Contengut de la rubrica en quaucu mots.)',
	'entree_identifiants_connexion' => 'Lu vòstres identificants de connexion...',
	'entree_informations_connexion_ldap' => 'Vorgatz intrar dins aqueu formulari li informacions de connexion au vòstre annuari LDAP.
L’administrator dau sistèma ò de la ret vos deu poder fornir
 aqueli informacions.', # MODIF
	'entree_infos_perso' => 'Cu siatz?',
	'entree_interieur_rubrique' => 'Dintre la rubrica:',
	'entree_liens_sites' => '<b>Ligam ipertèxt</b> (referéncia, sit de vesitar...)',
	'entree_login' => 'Lo vòstre login',
	'entree_login_connexion_1' => 'Lo login de connexion',
	'entree_login_connexion_2' => '(Correspònde de còups au vòstre login d’accès a l’FTP; de còups si laissa vuei)',
	'entree_mot_passe' => 'Lo vòstre senhau',
	'entree_mot_passe_1' => 'Senhau per la connexion',
	'entree_mot_passe_2' => '(Correspònde de còups au vòstre senhal per l’FTP; de còups si laissa vuei)',
	'entree_nom_fichier' => 'Vorgatz intrar lo nom dau fichier @texte_compresse@:',
	'entree_nom_pseudo' => 'Lo vòstre nom ò lo vòstre pseudonim',
	'entree_nom_pseudo_1' => '(Lo vòstre nom ò lo vòstre pseudonim)',
	'entree_nom_site' => 'Lo nom dau vòstre sit',
	'entree_nouveau_passe' => 'Mot de santa Clara novèu',
	'entree_passe_ldap' => 'Senhau',
	'entree_port_annuaire' => 'Lo número de pòrt de l’annuari',
	'entree_signature' => 'Signatura',
	'entree_titre_obligatoire' => '<b>Títol</b> [Obligatòri]<br />',
	'entree_url' => 'L’adreiça (URL) dau vòstre sit',

	// I
	'ical_info1' => 'Aquela pàgina mòstra de metòdes diferents per restar en contacte emb la vida d’aqueu sit.',
	'ical_info2' => 'Per tenir mai d’informacions sobre aqueli tecnicas, non esitetz de consultar <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'I a doi calendiers a la vòstra disposicion. Lo primier es un plan dau sit qu’anóncia toi lu articles publicats. Lo segond conten lu anoncis editoriaus en mai dei vòstres darriers messatges privats: v’es reservat gaug a una clau personala, que la podètz modificar en tot moment en renovant lo vòstre senhau. ',
	'ical_methode_http' => 'Telecargament',
	'ical_methode_webcal' => 'Sincronizacion (webcal://)', # MODIF
	'ical_texte_prive' => 'Aqueu calendier, d’us estrictament personau, v’informa de l’activitat editoriala privada d’aqueu sit (òbras e rendètz-vos personaus, articles e brèvas prepauats...).',
	'ical_texte_public' => 'Aqueu calendier vos permete de sègre l’activitat publica d’aqueu sit (articles e brèvas publicats).',
	'ical_texte_rss' => 'Podètz sindicar li novetats d’aquest sit dins quin legidor de fichiers que sia en format XML/RSS (Rich Site Summary). Es finda lo format que permete a SPIP de legir li novetats publicadi dins d’autres sits en utilizant un format d’escambi compatible (sits sindicats). ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lista de corrier',
	'ical_titre_rss' => 'Fichiers «backend»', # MODIF
	'icone_activer_cookie' => 'Activar lo cookie de correspondéncia',
	'icone_afficher_auteurs' => 'Afichar lu autors',
	'icone_afficher_visiteurs' => 'Afichar lu vesitaires',
	'icone_arret_discussion' => 'Quitar aquela discussion',
	'icone_calendrier' => 'Calendier',
	'icone_creer_auteur' => 'Crear un autor nòu e l’associar a aquel article',
	'icone_creer_mot_cle' => 'Crear un mot clau nòu e lo ligar a aquel article',
	'icone_creer_rubrique_2' => 'Crear una rubrica nòva',
	'icone_modifier_article' => 'Modificar aquel article',
	'icone_modifier_rubrique' => 'Modificar aquela rubrica',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’article',
	'icone_supprimer_cookie' => 'Suprimir lo cookie de correspondéncia',
	'icone_supprimer_rubrique' => 'Suprimir aquela rubrica',
	'icone_supprimer_signature' => 'Suprimir aquela signatura',
	'icone_valider_signature' => 'Validar aquela signatura',
	'image_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 article',
	'info_activer_cookie' => 'Podètz activar un <b>cookie de correspondéncia</b>; aquò vos permetrà de passar aisat dau sit public au sit privat.',
	'info_administrateur' => 'Administrator', # MODIF
	'info_administrateur_1' => 'Administrator', # MODIF
	'info_administrateur_2' => 'dau sit(<i>d’utilizar emb precaucion</i>)',
	'info_administrateur_site_01' => 'Se siatz administrator/tritz dau sit, vorgatz', # MODIF
	'info_administrateur_site_02' => 'clicar aqueu liame',
	'info_administrateurs' => 'Administrators', # MODIF
	'info_administrer_rubrique' => 'Podètz administrar aquela rubrica',
	'info_adresse' => 'a l’adreiça:',
	'info_adresse_url' => 'Adreiça (URL) dau sit public',
	'info_aide_en_ligne' => 'Ajuda en linha SPIP',
	'info_ajout_image' => 'Quand apondètz d’imatges coma estacaments jonchs a un article, SPIP pòu crear automaticament per vos de vinhetas (miniaturas) dei imatges inserits. Aquò permete per exemple de crear automaticament una galaria ò un pòrtfòlio.',
	'info_ajouter_rubrique' => 'Apondre una autra rubrica d’administrar:',
	'info_annonce_nouveautes' => 'Anonci dei novetats',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Lu articles pòstdatats per paréisser',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Lu articles d’aquel autor',
	'info_articles_trouves' => 'Articles trobats',
	'info_attente_validation' => 'Lu vòstres articles en espèra de validacion',
	'info_aujourdhui' => 'ancuei:',
	'info_auteurs' => 'Lu autors',
	'info_auteurs_par_tri' => 'autors@partri@',
	'info_auteurs_trouves' => 'Autors trobats',
	'info_authentification_externe' => 'Autentificacion extèrna',
	'info_avertissement' => 'Avís',
	'info_base_installee' => 'L’estructura de la vòstra basa de donadas es installada.',
	'info_chapeau' => 'Capèu',
	'info_chapeau_2' => 'Capèu:',
	'info_chemin_acces_1' => 'Opcions: <b>camin d’accès dins l’annuari</b>',
	'info_chemin_acces_2' => 'Aüra devètz configurar lo camin d’accès ai informacions dins l’annuari.', # MODIF
	'info_chemin_acces_annuaire' => 'Opcions: <b>camin d’accès dins l’annuari',
	'info_choix_base' => 'Tèrça estapa:',
	'info_classement_1' => '<sup>ier</sup> de @liste@',
	'info_classement_2' => '<sup>nd</sup> de @liste@',
	'info_code_acces' => 'Non oblidetz lu vòstres còdes d’accès pròpris!',
	'info_config_suivi' => 'S’aquela adreiça correspònde a una lista de corrier, podètz indicar çai sota l’adreiça dont lu participants au sit si pòdon inscriure. Aquela adreiça pòu èstre una URL (per exemple la pàgina d’inscripcion a la lista per lo web), ò una adreiça e-mail tenent un subjècte especific (per exemple: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Vos podètz abonar a la lista de difusion d’aquest sit. Alora recebretz per e-mail lu anoncis d’articles e de brèvas que si prepaua a la publicacion.',
	'info_confirmer_passe' => 'Confirmar aqueu mot de santa Clara novèu:',
	'info_connexion_base' => 'Segonda estapa: <b>Assai de connexion a la basa</b>',
	'info_connexion_ldap_ok' => 'La connexion LDAP a capitat.</b><p> Podètz passar a l’estapa seguenta.</p>', # MODIF
	'info_connexion_mysql' => 'Primiera estapa: <b>La vòstra connexion SQL</b>',
	'info_connexion_ok' => 'La connexion a capitat.',
	'info_contact' => 'Contacte',
	'info_contenu_articles' => 'Contengut dei articles',
	'info_creation_paragraphe' => '(Per crear de paragrafs, basta que laissetz de linhas vueii.)', # MODIF
	'info_creation_rubrique' => 'Avans de poder escriure d’articles,<br /> devètz crear aumens una rubrica.<br />',
	'info_creation_tables' => 'Quarta estapa: <b>Creacion dei taulas de la basa</b>',
	'info_creer_base' => '<b>Crear</b> una basa de donadas novèla:',
	'info_dans_rubrique' => 'Dins la rubrica:',
	'info_date_publication_anterieure' => 'Data anteriora de publicacion:',
	'info_date_referencement' => 'DATA DE REFERENCIAMENT D’AQUEU SIT:',
	'info_derniere_etape' => 'Darriera estapa: <b>Es acabat!',
	'info_descriptif' => 'Descriptiu:',
	'info_discussion_cours' => 'Discussions en cors',
	'info_ecrire_article' => 'Avans de poder escriure d’articles, vos cau crear aumens una rubrica.',
	'info_email_envoi' => 'Adreiça e-mail de mandadís (opcionau)',
	'info_email_envoi_txt' => 'Indicatz aicí l’adreiça d’utilizar per enviar lu e-mails (a fauta d’aquò, s’utilizarà l’adreiça destinatari coma adreiça de mandadís):',
	'info_email_webmestre' => 'Adreiça e-mail dau responsable dau sit (opcionau)', # MODIF
	'info_envoi_email_automatique' => 'Mandadís d’e-mails automatics',
	'info_envoyer_maintenant' => 'Mandar aüra',
	'info_etape_suivante' => 'Passar a l’estapa seguenta',
	'info_etape_suivante_1' => 'Podètz passar a l’estapa seguenta.',
	'info_etape_suivante_2' => 'Podètz passar a l’estapa seguenta.',
	'info_exportation_base' => 'exportacion de la basa vèrs @archive@',
	'info_facilite_suivi_activite' => 'Per facilitar lo segut de l’activitat editoriala dau sit, SPIP vos pòu fornir per e-mail, per exemple a una lista de corrier dei redactors, l’anonci dei demandas de publicacion e dei validacions d’articles.', # MODIF
	'info_fichiers_authent' => 'Fichiers d’autentificacion « .htpasswd »',
	'info_forums_abo_invites' => 'Lo vòstre sit web pòrge de forums per lu abonats; dins lo sit public lu vesitaires son convidats a si registrar.', # MODIF
	'info_gauche_admin_tech' => '<b>A aquela pàgina, basta lu responsables dau sit i pòdon accedir.</b><p> Permete de trobar li diferenti foncions de mantenença tecnica. D’uni que i a implican un procès d’autentificacion especific, que necessita un accès FTP au sit web.</p>', # MODIF
	'info_gauche_auteurs' => 'Trobaretz aicí toi lu autors dau sit. La color dei icònas n’indica l’estatut (administrator = verd; redactor = jaune).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Lu autors exteriors, sensa accès au sit, son indicats per una icòna blava; lu autors esfaçats per un bordilhier.', # MODIF
	'info_gauche_messagerie' => 'La messatjaria vos permete d’escambiar de messatges entre redactors, de servar de mementos (per lo vòstre usatge personau) o d’afichar d’anoncis sus la pàgina d’acuelh de l’espaci privat (se siatz administrator/tritz).', # MODIF
	'info_gauche_statistiques_referers' => 'Aquela pàgina presenta la lista dei <i>referidors</i>, valent a dire dei sits que contenon de ligams menant vèrs lo vòstre sit pròpri, mas unicament per ièr e ancuei: aquela lista s’actualiza cada 24 oras.',
	'info_gauche_visiteurs_enregistres' => 'Trobaretz aquí lu vesitaires registrats
 dins l’espaci public dau sit (forums emb abonament).',
	'info_generation_miniatures_images' => 'Congreacion de miniaturas dei imatges',
	'info_hebergeur_desactiver_envoi_email' => 'D’unu aubergadors desactivan lo mandadís automatic
 d’e-mails despí lu sieus servidors. En aqueu cas, li foncionalitats seguenti
 d’SPIP non foncionaràn.',
	'info_hier' => 'ièr:',
	'info_identification_publique' => 'La vòstra identitat publica...',
	'info_image_process' => 'Vorgatz seleccionar lo melhor metòde de fabricacion dei vinhetas en clicant sus l’imatge correspondent.',
	'info_image_process2' => '<b>N.B.</b> <i>Se minga d’imatge apareisse, alora lo servidor qu’aubèrga lo vòstre sit non l’an configurat per utilizar d’aisinas tali. Se desiratz d’utilizar aqueli foncions, contactatz lo responsable tecnic e demandatz li extensions «GD» ò «Imagick».</i>', # MODIF
	'info_images_auto' => 'Imatges calculats automaticament',
	'info_informations_personnelles' => 'Cinquena estapa: <b>Informacions personali</b>',
	'info_inscription_automatique' => 'Inscripcion automatica de redactors novèus', # MODIF
	'info_jeu_caractere' => 'Juec de caractèrs dau sit',
	'info_jours' => 'jorns',
	'info_laisser_champs_vides' => 'laissar aquelu camps vueis)',
	'info_langues' => 'Lengas dau sit',
	'info_ldap_ok' => 'L’autentificacion LDAP es installada.',
	'info_lien_hypertexte' => 'Ligam ipertèxt:',
	'info_liste_redacteurs_connectes' => 'Tiera dei redactors connectats', # MODIF
	'info_login_existant' => 'Aqueu login ja existisse.',
	'info_login_trop_court' => 'Login tròup cort.',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'Dins la meteissa rubrica',
	'info_message_en_redaction' => 'Lu vòstres messatges en cors de redaccion',
	'info_message_technique' => 'Messatge tecnic:',
	'info_messagerie_interne' => 'Messatjaria intèrna',
	'info_mise_a_niveau_base' => 'Mesa a nivèu de la vòstra basa SQL',
	'info_mise_a_niveau_base_2' => '{{Atencion!}} Avètz installada una version
  dei fichiers SPIP {anteriora} a la que i avia
  avans sus aquest sit: riscatz de pèrdre la vòstra basa de donadas
   e lo vòstre sit foncionarà pus.<br />{{Tornatz installar lu
  fichiers d’SPIP.}}',
	'info_modifier_rubrique' => 'Modificar la rubrica:',
	'info_modifier_titre' => 'Modificar: @titre@',
	'info_mon_site_spip' => 'Lo mieu sit SPIP',
	'info_moyenne' => 'mejana:',
	'info_multi_cet_article' => 'Lenga d’aquest article:',
	'info_multi_langues_choisies' => 'Vorgatz seleccionar çai sota li lengas que son a posita dei redactors dau vòstre sit.
  Li lengas ja emplegadi dins lo vòstre sit (afichadi d’en primier) non si pòdon desactivar.', # MODIF
	'info_multi_secteurs' => '... basta per li rubricas a la raiç dau sit?',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom dau destinatari',
	'info_nom_site' => 'Nom dau vòstre sit',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ rubricas,',
	'info_nombre_sites' => '@nb_sites@ sits,',
	'info_non_deplacer' => 'De non desplaçar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pòu mandar, regularament, l’anonci dei darrieri novetats dau sit
 (articles e brèvas publicats recentament).',
	'info_non_envoi_liste_nouveautes' => 'Non mandar la tiera dei novetats',
	'info_non_modifiable' => 'non si pòu modificar',
	'info_non_suppression_mot_cle' => 'non vòli suprimir aqueu mot clau.',
	'info_notes' => 'Nòtas',
	'info_nouvel_article' => 'Article nòu',
	'info_nouvelle_traduction' => 'Revirada nòva:',
	'info_numero_article' => 'ARTICLE NÚMERO:',
	'info_obligatoire_02' => '[Obligatòri]', # MODIF
	'info_option_accepter_visiteurs' => 'Acceptar l’inscripcion dei vesitaires dau sit public', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Refusar l’inscripcion de vesitaires', # MODIF
	'info_options_avancees' => 'OPCIONS AVANÇADI',
	'info_ou' => 'ò... ',
	'info_page_interdite' => 'Pàgina proïbida',
	'info_par_nombre_article' => '(per nombre d’articles)',
	'info_passe_trop_court' => 'Mot de santa Clara tròp cort.',
	'info_passes_identiques' => 'Lu doi mots de santa Clara non son identics.',
	'info_plus_cinq_car' => 'mai de 5 caractèrs',
	'info_plus_cinq_car_2' => '(mai de 5 caractèrs)',
	'info_plus_trois_car' => '(mai de 3 caractèrs)',
	'info_popularite' => 'popularitat: @popularite@; vesitas: @visites@',
	'info_post_scriptum' => 'Post-scriptum',
	'info_post_scriptum_2' => 'Post-scriptum:',
	'info_pour' => 'per',
	'info_preview_texte' => 'Es possible de previsualizar lo sit coma s’avian publicat toi lu articles e brèvas (que tenon aumens l’estatut "prepauat"). La cau durbir, aquela possibilitat, basta ai administrators, a toi lu redactors, ò en degun?', # MODIF
	'info_procedez_par_etape' => 'procedissètz estapa per estapa',
	'info_procedure_maj_version' => 'Cau lançar la procedura d’actualizacion per adaptar
 la basa de donadas a la version novèla d’SPIP.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Lu vòstres articles publicats en linha',
	'info_question_accepter_visiteurs' => 'S’ai esqueletas dau vòstre sit web si prevé lo registrament de vesitaires sensa accès a l’espaci privat, vorgatz activar l’opcion seguenta:', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Acceptatz que de redactors novèus s’inscrigan
 a partir dau sit public? S’o acceptatz, lu vesitaires si porràn inscriure
 gaug a un formulari automatizat e alora accediràn a l’espaci privat per
 prepauar d’articles.<blockquote><i> Durant la fasa d’inscripcion, lu utilizaires recebon un e-mail automatic
 que li dona un còde d’accès au sit privat.
D’unu aubergadors non autorizan lo mandadís d’e-mails despí lu sieus servidors: en aqueu cas, l’inscripcion automatica es
 impossibla.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Raiç dau sit',
	'info_recharger_page' => 'Vorgatz tornar cargar aquela pàgina dins un momenton.',
	'info_recherche_auteur_zero' => '<b>Minga de resultat trobat per "@cherche_auteur@".',
	'info_recommencer' => 'Vorgatz tornar començar.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'qu’accedisse a l’espaci privat (<i>recomandat</i>)',
	'info_redacteurs' => 'Redactors',
	'info_redaction_en_cours' => 'EN CORS DE REDACCION',
	'info_redirection' => 'Redireccion',
	'info_refuses' => 'Lu vòstres articles refusats',
	'info_reglage_ldap' => 'Opcions: <b>Reglatge de l’importacion LDAP</b>',
	'info_renvoi_article' => '<b>Redireccion.</b> Aquel article remanda a la pàgina:',
	'info_reserve_admin' => 'Basta lu administrators pòdon modificar aquela adreiça.', # MODIF
	'info_restreindre_rubrique' => 'Restrénher la gestion a la rubrica:',
	'info_resultat_recherche' => 'Resultats de la cèrca:',
	'info_rubriques' => 'Rubricas',
	'info_rubriques_02' => 'rubricas',
	'info_rubriques_trouvees' => 'Rubricas trobadi',
	'info_sans_titre' => 'Sensa títol',
	'info_selection_chemin_acces' => '<b>Seleccionatz</b> çai sota lo camin d’accès dins l’annuari:',
	'info_signatures' => 'signaturas',
	'info_site' => 'Sit',
	'info_site_2' => 'sit: ',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referenciat',
	'info_site_web' => 'SIT WEB:', # MODIF
	'info_sites' => 'sits',
	'info_sites_lies_mot' => 'Lu sits referenciats ligats a aqueu mot clau',
	'info_sites_proxy' => 'Utilizar un proxy',
	'info_sites_trouves' => 'Sits trobats',
	'info_sous_titre' => 'Sostítol:',
	'info_statut_administrateur' => 'Administrator', # MODIF
	'info_statut_auteur' => 'Estatut d’aquel autor:', # MODIF
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estatut predefinit dei utilizaires importats', # MODIF
	'info_statut_utilisateurs_2' => 'Chausissètz l’estatut d’atribuir ai personas presenti dins l’annuari LDAP quora si connèctan per lo primier còup. Porretz pi modificar aquel estatut per cada autor un cas per un.', # MODIF
	'info_suivi_activite' => 'Segut de l’activitat editoriala',
	'info_surtitre' => 'Sobretítol:',
	'info_taille_maximale_vignette' => 'Talha maximala dei vinhetas congreadi per lo sistèma:',
	'info_terminer_installation' => 'Aüra podètz acabar la procedura d’installacion estandard.',
	'info_texte' => 'Tèxt',
	'info_texte_explicatif' => 'Tèxt explicatiu',
	'info_texte_long' => '(lo tèxt es lòng: apareisse doncas en tròç distints que si tornaràn empegar un còup validats.)',
	'info_texte_message' => 'Tèxt dau vòstre messatge:', # MODIF
	'info_texte_message_02' => 'Tèxt dau messatge',
	'info_titre' => 'Títol:',
	'info_total' => 'totau: ',
	'info_tous_articles_en_redaction' => 'Toi lu articles en cors de redaccion',
	'info_tous_articles_presents' => 'Toi lu articles publicats dins aquela rubrica',
	'info_tous_les' => 'toi lu:',
	'info_tout_site' => 'Tot lo sit',
	'info_tout_site2' => 'Non an revirat l’article dins aquela lenga.',
	'info_tout_site3' => 'An revirat l’article dins aquela lenga, mas an portat pi de modificacions a l’article de referéncia. Cau actualizar la revirada.',
	'info_tout_site4' => 'An revirat l’article dins aquela lenga, e la revirada es actualizada.',
	'info_tout_site5' => 'Article originau.',
	'info_tout_site6' => '<b>Atencion:</b> basta lu articles originaus s’afichan.
Li reviradas s’assòcian a l’originau,
un color indica lo sieu estat:',
	'info_travail_colaboratif' => 'Trabalh collaboratiu sobre lu articles',
	'info_un_article' => 'un article, ',
	'info_un_site' => 'un sit, ',
	'info_une_rubrique' => 'una rubrica, ',
	'info_une_rubrique_02' => '1 rubrica',
	'info_url' => 'URL:',
	'info_urlref' => 'Ligam ipertèxt:',
	'info_utilisation_spip' => 'Aüra podètz començar d’utilizar lo sistèma de publicacion assistida...',
	'info_visites_par_mois' => 'Afichatge per mes:',
	'info_visiteur_1' => 'Vesitaire',
	'info_visiteur_2' => 'dau sit public',
	'info_visiteurs' => 'Vesitaires',
	'info_visiteurs_02' => 'Vesitaires dau sit public',
	'install_echec_annonce' => 'L’installacion capitarà mau, ò abotirà a un sit non foncionau...',
	'install_extension_mbstring' => 'SPIP non fonciona emb:',
	'install_extension_php_obligatoire' => 'SPIP exigisse l’extension php:',
	'install_select_langue' => 'Seleccionatz una lenga pi clicatz lo boton «seguent» per amodar la procedura d’installacion.',
	'intem_redacteur' => 'redactor',
	'item_accepter_inscriptions' => 'Acceptar li inscripcions',
	'item_activer_messages_avertissement' => 'Activar lu messatges d’avertiment',
	'item_administrateur_2' => 'administrator', # MODIF
	'item_afficher_calendrier' => 'Afichar dins lo calendier',
	'item_choix_administrateurs' => 'lu administrators', # MODIF
	'item_choix_generation_miniature' => 'Congrear automaticament li miniaturas dei imatges.',
	'item_choix_non_generation_miniature' => 'Congrear minga de miniaturas dei imatges.',
	'item_choix_redacteurs' => 'lu redactors',
	'item_choix_visiteurs' => 'lu vesitaires dau sit public',
	'item_creer_fichiers_authent' => 'Crear de fichiers .htpasswd',
	'item_login' => 'Login',
	'item_mots_cles_association_articles' => 'ai articles',
	'item_mots_cles_association_rubriques' => 'ai rubricas',
	'item_mots_cles_association_sites' => 'ai sits referenciats ò sindicats',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Non acceptar li inscripcions',
	'item_non_activer_messages_avertissement' => 'Minga de messatge d’avertiment',
	'item_non_afficher_calendrier' => 'De non afichar dins lo calendier',
	'item_non_creer_fichiers_authent' => 'Non crear aquelu fichiers',
	'item_non_publier_articles' => 'Non publicar lu articles avans la data de publicacion prevista.',
	'item_nouvel_auteur' => 'Autor nòu',
	'item_nouvelle_rubrique' => 'Rubrica nòva',
	'item_oui' => 'Aí',
	'item_publier_articles' => 'Publicar lu articles, quina que sia la sieu data de publicacion',
	'item_reponse_article' => 'Respòsta a l’article',
	'item_visiteur' => 'vesitaire',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'Apondre aquel autor',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NOM DAU SIT:',
	'lien_retirer_auteur' => 'Levar l’autor',
	'lien_site' => 'sit',
	'lien_tout_deplier' => 'Desplegar tot',
	'lien_tout_replier' => 'Tornar plegar',
	'lien_trier_nom' => 'Triar per nom',
	'lien_trier_nombre_articles' => 'Triar per nombre d’articles',
	'lien_trier_statut' => 'Triar per estatut',
	'lien_voir_en_ligne' => 'VEIRE EN LINHA:',
	'logo_article' => 'LÒGO DE L’ARTICLE', # MODIF
	'logo_auteur' => 'LÒGO DE L’AUTOR', # MODIF
	'logo_rubrique' => 'LÒGO DE LA RUBRICA', # MODIF
	'logo_site' => 'LÒGO D’AQUEU SIT', # MODIF
	'logo_standard_rubrique' => 'LÒGO ESTANDARD DEI RUBRICAS', # MODIF
	'logo_survol' => 'LÒGO PER LO SUBREVÒL', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Chausida de la vòstra basa',
	'module_fichier_langue' => 'Fichier de lenga',
	'module_raccourci' => 'Acorcha',
	'module_texte_affiche' => 'Tèxt afichat',
	'module_texte_explicatif' => 'Podètz inserir li acorchas seguenti dins li esqueletas dau vòstre sit public. Si reviraràn automaticament  dins li diferenti lengas per li quali existisse un fichier de lenga.',
	'module_texte_traduction' => 'Lo fichier de lenga «@module@» es disponible en:',
	'mois_non_connu' => 'non conegut',

	// O
	'onglet_repartition_actuelle' => 'd’aquesta passa',

	// R
	'required' => '[Obligatòri]', # MODIF

	// S
	'statut_admin_restreint' => '(admin. restrench)', # MODIF

	// T
	'taille_cache_image' => 'Lu imatges qu’SPIP a calculat automaticament (vinhetas dei documents, títols presentats en forma grafica, foncions matematiqui en format TeX...) ocupan dins lo repertòri @dir@ un totau de @taille@.',
	'taille_cache_octets' => 'Aüra la talha de l’escondedor compassa @octets@.', # MODIF
	'taille_cache_vide' => 'L’escondedor es vuei.',
	'taille_repertoire_cache' => 'Talha dau repertòri escondedor',
	'text_article_propose_publication' => 'Article prepauat per la publicacion. Non esitetz de donar lo vòstre vejaire gaug au forum estacat a aquel article (en bas de pàgina).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'D’unu servidors LDAP accèptan minga d’accès anonim. En aqueu cas, cau especificar un identificant d’accès iniciau per poder pi cercar d’informacions dins l’annuari. Totun, lu camps seguents si porràn laissar vueis dins la màger part dei cas.',
	'texte_admin_effacer_01' => 'Aquela comanda esfaça <i>tot</i> lo contengut de la basa de donadas,
 inclús <i>toi</i> lu accès redactors e administrators. Un còup que l’auretz executada, auretz de tornar lançar l’installacion d’SPIP per tornar crear una basa novèla e finda un primier accès administrator.', # MODIF
	'texte_adresse_annuaire_1' => '(Se lo vòstre annuari es installat sus la meteissa maquina qu’aqueu sit web, s’agisse probable de "localhost".)',
	'texte_ajout_auteur' => 'L’autor seguent es estat apondut a l’article:',
	'texte_annuaire_ldap_1' => 'S’accedissètz a un annuari (LDAP), lo podètz utilizar per importar automaticament d’utilizaires sota SPIP.', # MODIF
	'texte_article_statut' => 'Aquel article es:',
	'texte_article_virtuel' => 'Article virtuau',
	'texte_article_virtuel_reference' => '<b>Article virtuau:</b> article referenciat dins lo vòstre sit SPIP, mas redirigit vèrs una autra URL. Per suprimir la redireccion, esfaçatz l’URL çai sobre.',
	'texte_aucun_resultat_auteur' => 'Minga de resultat per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Aquest sit vos pòu indicar de contunha la tiera dei redactors connectats, cen que vos permete d’escambiar de messatges en dirècte. Podètz decidir de non aparéisser dins aquela lista (siatz "invisible/a" per lu autres utilizaires).', # MODIF
	'texte_auteurs' => 'LU AUTORS',
	'texte_choix_base_1' => 'Chausissètz la vòstra basa:',
	'texte_choix_base_2' => 'Lo servidor SQL conten mai d’una basa de donadas.',
	'texte_choix_base_3' => '<b>Chausissètz</b> çai sota aquela que lo vòstre aubergador v’a atribuida:',
	'texte_compte_element' => '@count@ element',
	'texte_compte_elements' => '@count@ elements',
	'texte_connexion_mysql' => 'Consultatz li informacions que lo vòstre aubergador fornisse: i devètz trobar, se lo vòstre aubergador supòrta SQL, lu còdes de connexion au servidor SQL.', # MODIF
	'texte_contenu_article' => '(Contengut de l’article en quaucu mots.)',
	'texte_contenu_articles' => 'Segon la maqueta que lo vòstre sit a adoptada, podètz decidir
 que certans elements dei articles non s’utilizen.
 Utilizatz la tiera çai sota per indicar quins elements son disponibles.',
	'texte_crash_base' => 'Se la vòstra basa de donadas s’es
 encalada, podètz assaiar una reparacion
 automatica.',
	'texte_creer_rubrique' => 'Avans de poder escriure d’articles,<br /> devètz crear una rubrica.',
	'texte_date_creation_article' => 'DATA DE CREACION DE L’ARTICLE:',
	'texte_date_publication_anterieure' => 'DATA DE PUBLICACION ANTERIORA:',
	'texte_date_publication_anterieure_nonaffichee' => 'Afichar minga de data de publicacion anteriora.',
	'texte_date_publication_article' => 'DATA DE PUBLICACION EN LINHA:',
	'texte_descriptif_rapide' => 'Descriptiu rapid',
	'texte_effacer_base' => 'Esfaçar la basa de donadas SPIP',
	'texte_en_cours_validation' => 'Si prepaua de publicar lu articles e brèvas çai sota. Non esitetz de donar lo vòstre vejaire gaug ai forums que i son estacats.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Podètz enriquir la compaginacion dau vòstre tèxt en utilizant d’"acorchas tipografiqui".',
	'texte_fichier_authent' => '<b>Deu crear, SPIP, de fichiers especiaus  <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> dins lo repertòri @dossier@?</b><p>
  Aquelu fichiers vos pòdon servir per restrénher l’accès ai autors
  e administrators en d’autres luecs dins lo vòstre sit
  (programa extèrne d’estadisticas, per exemple).<p>
 Se non vos sèrve, podètz laissar aquesta opcion
  au sieu valor predefinit (minga de creacion
  dei fichiers).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Aüra lo sistèma vos crearà un accès personalizat au sit.',
	'texte_informations_personnelles_2' => '(Nòta: se s’agisse d’una reïnstallacion, e se lo vòstre accès fonciona encara, podètz', # MODIF
	'texte_introductif_article' => '(Tèxt introductiu de l’article.)',
	'texte_jeu_caractere' => 'Aquesta opcion es utila se lo vòstre sit deu afichar d’alfabets
 diferents de l’alfabet latin (ò "occidentau") e lu sieus derivats.
 En aqueu cas, cau cambiar lo reglatge predefinit per fin d’utilizar
 un juec de caractèrs apropriat. Non oblidetz nimai d’adaptar
 lo sit public en consequéncia (balisa <tt>#CHARSET</tt>).', # MODIF
	'texte_login_ldap_1' => '(Laissar vuei per un accès anonim, ò picar lo camin complet, per exemple «<tt>uid=fabre, ou=usanciers, dc=mon-domeni, dc=com</tt>».)',
	'texte_login_precaution' => 'Atencion! Aquò es lo login emb lo quau siatz aüra connectat/ada. 
 Utilizatz aquest formulari emb precaucion...',
	'texte_mise_a_niveau_base_1' => 'Venètz d’actualizar lu fichiers SPIP.
 Aüra cau metre a nivèu la basa de donadas
 dau sit.',
	'texte_modifier_article' => 'Modificar l’article:',
	'texte_multilinguisme' => 'Se desiratz de gerir d’articles en plusors lengas, emb una navigacion complèxa, podètz apondre un menut per chausir la lenga dei articles e/ò dei rubricas, en foncion de l’organizacion dau vòstre sit.', # MODIF
	'texte_multilinguisme_trad' => 'Podètz finda activar un sistèma de gestion dei ligams entre li diferenti reviradas d’un article.', # MODIF
	'texte_non_compresse' => '<i>non comprimit</i> (perque lo vòstre servidor non supòrta aquela foncionalitat)',
	'texte_nouvelle_version_spip_1' => 'Avètz installada una version novèla d’SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquesta version novèla demanda una actualizacion mai completa que de costuma. Se siatz webmèstre/webmèstra dau sit, vorgatz esfaçar lo fichier <tt>inc_connect.php3</tt> dau repertòri <tt>ecrire</tt> e tornar pilhar l’installacion per fin d’actualizar lu vòstres paramètres de connexion a la basa de donadas.<p> (NB: s’avètz demembrat lu vòstres paramètres de connexion, espepissatz lo fichier  <tt>inc_connect.php3</tt> avans de lo suprimir...)</p>', # MODIF
	'texte_operation_echec' => 'Tornatz a la pàgina precedenta, chausissètz una autra basa ò creatz-ne’n una novèla. Verificatz li informacions que lo vòstre aubergador a fornidi.',
	'texte_plus_trois_car' => 'mai de 3 caractèrs',
	'texte_plusieurs_articles' => 'Mai d’un autor trobat per "@cherche_auteur@":',
	'texte_port_annuaire' => '(Lo valor indicat coma predefinit conven en generau.)',
	'texte_proposer_publication' => 'Quora auretz acabat lo vòstre article,<br /> porretz prepauar que sia publicat.',
	'texte_proxy' => 'Dins d’unu cas (intranet, rets protegidas...),
  si pòu que cauga utilizar un <i>proxy HTTP</i> per aténher lu sits sindicats.
  En aqueu cas, marcatz çai sota la sieu adreiça, sota la forma
  <tt><html>http://proxy:8080</html></tt>. En generau,
  laissaretz vueia aquela casa.',
	'texte_publication_articles_post_dates' => 'Coma SPIP si deu comportar fàcia ai articles que la sieu
  data de publicacion es fixada a una 
  escasença futura?',
	'texte_rappel_selection_champs' => '[Non oblidetz de seleccionar aqueu camp correctament.]',
	'texte_recalcul_page' => 'Se volètz
tornar calcular basta una pàgina, passatz pusprèst per l’espaci public e utilizatz lo  boton "tornar calcular".',
	'texte_recuperer_base' => 'Reparar la basa de donadas',
	'texte_reference_mais_redirige' => 'article referenciat dins lo vòstre sit SPIP, mas redirigit vèrs una autra URL.',
	'texte_requetes_echouent' => '<b>Quora d’uni requistas SQL s’encalan
  sistematicament e sensa rason aparenta, si pòu
  qu’aquò venga ben de la basa de donadas.  </b><p>
  SQL ten la facultat de reparar li sieus
  taulas quora un accident li
  a esquintadas. Aicí podètz assaiar aquela reparacion; se 
  non capita, servatz una còpia de l’afichatge, que conten
 benlèu d’indicis de cen que non va...</p><p>
  Se lo problèma persistisse, contactatz lo vòstre
  aubergador.</p>', # MODIF
	'texte_selection_langue_principale' => 'Podètz seleccionar çai sota la "lenga principala" dau sit. Aquela chausida non v’obliga -grand gaug- d’escriure lu vòstres articles dins la lenga seleccionada, mas permete de determinar:
 <ul><li> lo format predefinit dei datas sus lo sit public;</li>
 <li> la natura dau motor tipografic qu’SPIP deu utilizar per lo rendut dei tèxts;</li>
 <li> la lenga utilizada dins lu formularis dau sit public;</li>
 <li> la lenga presentada coma predefinida dins l’espaci privat.</li></ul>',
	'texte_sous_titre' => 'Sostítol',
	'texte_statistiques_visites' => '(barras escuri:  diménegue / corba escura: evolucion de la mejana)',
	'texte_statut_attente_validation' => 'en espèra de validacion',
	'texte_statut_publies' => 'publicats en linha',
	'texte_statut_refuses' => 'refusats',
	'texte_suppression_fichiers' => 'Utilizatz aquela comanda per suprimir toi lu fichiers que si tròban
dins l’escondedor SPIP. Aquò permete per exemple de forçar un calcul nòu de toti li pàginas
s’avètz bravament modificat lo grafisme ò l’estructura dau sit.',
	'texte_sur_titre' => 'Sobretítol',
	'texte_table_ok' => ': aquesta taula es condrecha.',
	'texte_tentative_recuperation' => 'Assai de reparacion',
	'texte_tenter_reparation' => 'Assaiar de reparar la basa de donadas',
	'texte_test_proxy' => 'Per assaiar aqueu proxy, indicatz aicí l’adreiça d’un sit web
    que lo vorriatz esprovar.',
	'texte_titre_02' => 'Títol:',
	'texte_titre_obligatoire' => '<b>Títol</b> [Obligatòri]',
	'texte_travail_article' => '@nom_auteur_modif@ a trabalhat sus aquel article fa @date_diff@ minutas',
	'texte_travail_collaboratif' => 'Quora es frequent que mai d’un redactor 
  trabalhe sus lo meteis article, lo sistèma
  pòu afichar lu articles recentament "dubèrts"
  per fin d’evitar li modificacions simultanèï.
  Aquela opcion es desactivada de maniera predefinida
  per fin d’evitar d’afichar de messatges d’avertiment
  intempestius.', # MODIF
	'texte_vide' => 'vuei',
	'texte_vider_cache' => 'Vuar l’escondedor',
	'titre_admin_tech' => 'Mantenença tecnica',
	'titre_cadre_afficher_article' => 'Afichar lu articles',
	'titre_cadre_afficher_traductions' => 'Afichar l’estat dei reviradas per aquela lenga',
	'titre_cadre_ajouter_auteur' => 'APONDRE UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'Dintre la rubrica',
	'titre_cadre_numero_auteur' => 'AUTOR NÚMERO',
	'titre_cadre_signature_obligatoire' => '<b>Signatura</b> [Obligatòria]<br />',
	'titre_config_fonctions' => 'Configuracion dau sit',
	'titre_configuration' => 'Configuracion dau sit',
	'titre_connexion_ldap' => 'Opcions: <b>La vòstra connexion LDAP</b>',
	'titre_groupe_mots' => 'GROP DE MOTS:',
	'titre_langue_article' => 'LENGA DE L’ARTICLE', # MODIF
	'titre_langue_rubrique' => 'LENGA DE LA RUBRICA', # MODIF
	'titre_langue_trad_article' => 'LENGA E REVIRADAS DE L’ARTICLE',
	'titre_les_articles' => 'LU ARTICLES',
	'titre_naviguer_dans_le_site' => 'Navigar per lo sit...',
	'titre_nouvelle_rubrique' => 'Rubrica novèla',
	'titre_numero_rubrique' => 'RUBRICA NÚMERO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Lu articles',
	'titre_page_articles_tous' => 'Tot lo sit',
	'titre_page_calendrier' => 'Calendier @nom_mois@ de @annee@',
	'titre_page_config_contenu' => 'Configuracion dau sit',
	'titre_page_delete_all' => 'supression totala e irreversibla',
	'titre_page_recherche' => 'Resultats de la cèrca @recherche@',
	'titre_page_statistiques_referers' => 'Estadisticas (ligams intrants)',
	'titre_page_upgrade' => 'Mesa a nivèu d’SPIP',
	'titre_publication_articles_post_dates' => 'Publicacion dei articles pòstdatats',
	'titre_reparation' => 'Reparacion',
	'titre_suivi_petition' => 'Segut dei peticions',
	'trad_article_traduction' => 'Toti li versions d’aquel article:',
	'trad_delier' => 'Cessar de ligar aquest article ai sieus reviradas ', # MODIF
	'trad_lier' => 'Aquest article es una revirada de l’article número:',
	'trad_new' => 'Escriure una revirada novèla d’aquest article', # MODIF
];
